@@ -4,6 +4,6 @@ class DownForMaintenanceError(BraintreeError):
     """
     Raised when the gateway is down for maintenance.
 
-    See http://www.braintreepaymentsolutions.com/docs/python/general/exceptions#down_for_maintenance_error
+    See http://www.braintreepayments.com/docs/python/general/exceptions#down_for_maintenance_error
     """
     pass
